package com.vaskoz.spring3.controllers;

import com.vaskoz.spring3.domain.Project;
import com.vaskoz.spring3.service.ProjectService;

import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.springframework.stereotype.Controller;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;
import java.util.List;

import javax.inject.Inject;


@Controller
@RequestMapping("/projects")
public class ProjectController {
	
	private ProjectService projectService;
	
	public ProjectController() {} // needed for a proxy, can't be private.
	
	@Inject
	public ProjectController(ProjectService projectService) {
		this.projectService = projectService;
	}

    @RequestMapping(method = RequestMethod.GET)
    @Transactional
    public ModelAndView index() {
    	List<Project> projects = this.projectService.getAllProjects();
        return new ModelAndView("projects/index", "projects", projects);
    }

    @RequestMapping(value="/{id}", method = RequestMethod.GET)
    @Transactional
    public ModelAndView show(@PathVariable Long id) {
    	Project project = this.projectService.findProjectById(id);
        return new ModelAndView("projects/show", "project", project);
    }

    @RequestMapping(value="/newProject", method=RequestMethod.GET)
    @Transactional
    public @ResponseBody String newData() {
    	Project project = new Project("project name", "and the description", new Date());
    	Project managedProject = this.projectService.createProject(project);
        return managedProject.toString();
    }

}
